@@ -1,7 +1,7 @@
 package App::IODUtils;
 
-our $VERSION = '0.05'; # VERSION
-our $DATE = '2015-03-18'; # DATE
+our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-03-19'; # DATE
 
 use 5.010001;
 
@@ -20,6 +20,11 @@ our %common_args = (
         cmdline_aliases => {e=>{}},
         tags    => ['common'],
     },
+    ignore_unknown_directive => {
+        schema  => 'bool',
+        default => 0,
+        tags    => ['common'],
+    },
 );
 
 our %inplace_arg = (
@@ -58,6 +63,26 @@ sub _return_mod_result {
     }
 }
 
+sub _get_parser {
+    require Config::IOD;
+
+    my $args = shift;
+    Config::IOD->new(
+        enable_expr=>$args->{enable_expr},
+        ignore_unknown_directive=>$args->{ignore_unknown_directive},
+    );
+}
+
+sub _get_reader {
+    require Config::IOD::Reader;
+
+    my $args = shift;
+    Config::IOD::Reader->new(
+        enable_expr=>$args->{enable_expr},
+        ignore_unknown_directive=>$args->{ignore_unknown_directive},
+    );
+}
+
 1;
 # ABSTRACT: IOD utilities
 
@@ -73,7 +98,7 @@ App::IODUtils - IOD utilities
 
 =head1 VERSION
 
-This document describes version 0.05 of App::IODUtils (from Perl distribution App-IODUtils), released on 2015-03-18.
+This document describes version 0.06 of App::IODUtils (from Perl distribution App-IODUtils), released on 2015-03-19.
 
 =head1 SYNOPSIS
 
